@@ -1,18 +1,11 @@
 
-import functools
-import timeit
-import numpy as np
-import pandas as pd
+
 import seaborn as sns
 import matplotlib.pyplot as plt
-from typing import Union
 from enum import Enum
 
 from qis.data.ust_rates import load_ust_rates
-import qis.models.linear.ewm as ewm
-import qis.models.linear.auto_corr as ac
-import qis.plots.utils as put
-import qis.plots.time_series as pts
+import qis.plots as qp
 
 
 def plot_ust_rates_data():
@@ -20,14 +13,14 @@ def plot_ust_rates_data():
 
     with sns.axes_style("darkgrid"):
         fig, ax = plt.subplots(1, 1, figsize=(10, 10), tight_layout=True)
-        pts.plot_time_series(df=df,
-                             legend_line_type=pts.LegendLineType.FIRST_AVG_LAST,
+        qp.plot_time_series(df=df,
+                             legend_stats=qp.LegendStats.FIRST_AVG_LAST,
                              var_format='{:,.2f}',
                              ax=ax)
 
         fig, ax = plt.subplots(1, 1, figsize=(10, 10), tight_layout=True)
-        pts.plot_time_series(df=df[['3m', '10y']],
-                             legend_line_type=pts.LegendLineType.FIRST_AVG_LAST,
+        qp.plot_time_series(df=df[['3m', '10y']],
+                             legend_stats=qp.LegendStats.FIRST_AVG_LAST,
                              var_format='{:,.2f}',
                              ax=ax)
 
